summaryrefslogtreecommitdiffstats
path: root/kmail/kmheaders.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmheaders.h')
-rw-r--r--kmail/kmheaders.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/kmheaders.h b/kmail/kmheaders.h
index e6bbe422..f504c3f3 100644
--- a/kmail/kmheaders.h
+++ b/kmail/kmheaders.h
@@ -53,7 +53,7 @@ class KMHeaders : public KListView
friend class ::KMail::HeaderItem; // For easy access to the pixmaps
public:
- KMHeaders(KMMainWidget *owner, TQWidget *tqparent=0, const char *name=0);
+ KMHeaders(KMMainWidget *owner, TQWidget *parent=0, const char *name=0);
virtual ~KMHeaders();
/** A new folder has been selected update the list of headers shown
@@ -114,7 +114,7 @@ public:
/** Returns the sernums of all selected items. */
TQValueList<TQ_UINT32> selectedSernums();
/** Returns the sernums of all visible (ie. items with expanded tqparent, not hidden by
eg. the quick search) selected items.
*/
TQValueList<TQ_UINT32> selectedVisibleSernums();
@@ -285,12 +285,12 @@ public slots:
virtual void ensureCurrentItemVisible();
/** Select an item and if it is the tqparent of a closed thread, also
recursively select its tqchildren. */
virtual void setSelected(TQListViewItem *item, bool selected);
/** Select several items by message index
* and if they are the tqparent of a closed thread, also
* recursively select their tqchildren. */
void setSelectedByIndex(TQValueList<int> items, bool selected);
@@ -114,7 +114,7 @@ public:
/** Returns the sernums of all selected items. */
TQValueList<TQ_UINT32> selectedSernums();
- /** Returns the sernums of all visible (ie. items with expanded tqparent, not hidden by
+ /** Returns the sernums of all visible (ie. items with expanded parent, not hidden by
eg. the quick search) selected items.
*/
@@ -285,12 +285,12 @@ public slots:
virtual void ensureCurrentItemVisible();
- /** Select an item and if it is the tqparent of a closed thread, also
+ /** Select an item and if it is the parent of a closed thread, also
recursively select its tqchildren. */
virtual void setSelected(TQListViewItem *item, bool selected);
@@ -285,12 +285,12 @@ public slots:
virtual void setSelected(TQListViewItem *item, bool selected);
/** Select several items by message index
- * and if they are the tqparent of a closed thread, also
+ * and if they are the parent of a closed thread, also
* recursively select their tqchildren. */
void setSelectedByIndex(TQValueList<int> items, bool selected);